@@ -37,12 +37,6 @@ patch ExtUtils/MM_Unix.pm mm_unix_pm '
 /^sub staticmake/,/^}/ s/if (@{$self->{C}}) {/if (@{$self->{C}} or $self->{NAME} =~ m%^(Pango|Gtk2)$%) { # patched by staticperl/
 '
 
-# patch ExtUtils::MM_Any *temporarily* because it breaks Pod::Parser
-patch ExtUtils/MM_Any.pm mm_any_pm '
-/^sub metafile_data/ a\
-   return; # patched by staticperl
-'
-
 # patch ExtUtils::Miniperl to always add DynaLoader
 # this is required for dynamic loading in static perls,
 # and static loading in dynamic perls, when rebuilding a new perl.
